#!/usr/bin/env python
# *********************************************************************
# * Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)         *
# *                                                                   *
# * For the license terms see the file LICENCE, distributed           *
# * along with this software.                                         *
# *********************************************************************
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


import ROOT
ROOT.gStyle.SetPalette(1)
ROOT.gStyle.SetCanvasColor(10)
ROOT.gStyle.SetFrameBorderMode(0)
ROOT.gStyle.SetFrameFillColor(0)
ROOT.gStyle.SetPadBorderMode(0)
ROOT.gStyle.SetPadColor(0)
ROOT.gStyle.SetHistFillStyle(0)
ROOT.gStyle.SetStatColor(10)
ROOT.gStyle.SetStatFont(42)
#ROOT.gStyle.SetLabelFont(42)
ROOT.gStyle.SetLabelFont(42,"xyz");
ROOT.gStyle.SetTitleFont(42,"xyz");
ROOT.gStyle.SetGridColor(16)
ROOT.gStyle.SetLegendBorderSize(1)
ROOT.gStyle.SetTitleYOffset(1.1)
ROOT.gStyle.SetOptTitle(0)
#ROOT.gStyle.SetOptStat(111111)
ROOT.gStyle.SetOptStat(10)
ROOT.gStyle.SetPaintTextFormat("1.2g")


if __name__ == '__main__':
    from optparse import OptionParser
    parser = OptionParser()
    (opts, args) = parser.parse_args()
    filePath = args[0]

    vals = [float(item) for item in open(filePath)]
    resolution = 4e-6
    xmin  = min(vals) - 1.5*resolution
    xmax  = max(vals) + 1.5*resolution
    xbins = int((xmax - xmin)/resolution + 0.5)
    h = ROOT.TH1F('h', 'h', xbins, xmin, xmax)
    g = ROOT.TGraph()
    g.SetMarkerStyle(24)
    i = 0
    for val in vals:
        h.Fill(val)
        g.SetPoint(i, i, val)
        i += 1

    ROOT.gStyle.SetOptFit(1111)

    c = ROOT.TCanvas('c', 'Time resolution', 800, 1000)
    c.Divide(1, 2)
    c.cd(1); h.Draw()
    c.Update()
    h.SetXTitle('#DeltaT [s]')
    h.SetYTitle('Entries/bin')
    ss = h.GetListOfFunctions().FindObject('stats')
    ss.SetY1NDC(0.92)
    #ggauss = ROOT.TF1("ggaus", "gaus(0)+gaus(3)",xmin, xmax)
    #ggauss.SetParameters(0.25*h.GetEntries(), xmin + 4*resolution, resolution, \
     #                    0.25*h.GetEntries(), xmax - 4*resolution, resolution)
    #ggauss.Draw("same")
    #ggauss.SetNpx(10000)
    #h.Fit('ggaus', "R")
    #h.Fit('gaus')
    c.cd(2); g.Draw('ap')
    g.GetXaxis().SetTitle('Measurement progressive number')
    g.GetYaxis().SetTitle('#DeltaT [s]')
    c.cd(); c.Update()
