#!/usr/bin/env python
# *********************************************************************
# * Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)         *
# *                                                                   *
# * For the license terms see the file LICENCE, distributed           *
# * along with this software.                                         *
# *********************************************************************
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


import PyQt4.Qwt5 as Qwt

from PyQt4 import Qt
from plasduino.gui.gQt import connect


class gStripChart(Qwt.QwtPlotCurve):
    
    """
    """

    def __init__(self, name, **kwargs):
        """ Constructor.
        """
        color = kwargs.get('color', Qt.Qt.blue)
        lineWidth = kwargs.get('lineWidth', 2)
        lineStyle = kwargs.get('lineStyle', Qt.Qt.SolidLine)
        markerSize = kwargs.get('markerSize', 8)
        markerBorder = kwargs.get('markerBorder', 1)
        Qwt.QwtPlotCurve.__init__(self, name)
        brush = Qt.QBrush(color)
        pen = Qt.QPen(brush, lineWidth, lineStyle)
        self.setPen(pen)
        if markerSize > 0:
            self.setSymbol(Qwt.QwtSymbol(Qwt.QwtSymbol.Ellipse, brush,
                                         Qt.QPen(Qt.Qt.black, markerBorder),
                                         Qt.QSize(markerSize, markerSize)))
        self.clear()

    def toggle(self):
        """ Change the visibility of the plot (i.e. hide it if it's visible
        and show it otherwise).
        """
        self.setVisible(not self.isVisible())

    def clear(self):
        """ Clear the data points.
        """
        self.DataX = []
        self.DataY = []
        self.StartTime = None
        self.setData(self.DataX, self.DataY)

    def addDataPoint(self, x, y):
        """ Add a data point to the strip chart.

        Note that we refer all the timestamps to the first one as to get
        rid of the (irrelevant) time offset in the readouts from arduino
        (where times are referred to the last reset of the board).
        """
        if self.StartTime is None:
            self.StartTime = x
        self.DataX.append(x - self.StartTime)
        self.DataY.append(y)
        self.setData(self.DataX, self.DataY)
        



if __name__ == '__main__':
    from plasduino.gui.gPlotWidget import gPlotWidget
    from plasduino.__cfgparse__ import getapp
    application = getapp()
    widget = gPlotWidget(xTitle = 'Elapsed time [s]', yTitle = 'ADC counts')
    chart = gStripChart('stripchart')
    chart.attach(widget)
    chart.setData([0, 1], [0, 1])
    widget.show()
    application.exec_()
